@@ -1,5 +1,5 @@
 package App::ansifold;
-our $VERSION = "1.33";
+our $VERSION = "1.34";
 
 use v5.14;
 use warnings;
@@ -17,6 +17,9 @@ use Text::ANSI::Fold::Util qw(ansi_width); {
 use Unicode::EastAsianWidth;
 use Data::Dumper;
 
+use Exporter 'import';
+our @EXPORT_OK = qw(ansifold ansiexpand ansicolrm ansicut);
+
 our $DEFAULT_WIDTH    //= 72;
 our $DEFAULT_SEPARATE //= "\n";
 our $DEFAULT_EXPAND   //= 0;
@@ -24,6 +27,27 @@ our $DEFAULT_COLRM    //= 0;
 our $DEFAULT_CUT      //= 0;
 our $DEFAULT_SPLITWIDE;
 
+sub ansifold {
+    __PACKAGE__->new->perform(@_);
+}
+
+sub ansiexpand {
+    local $DEFAULT_WIDTH  = -1;
+    local $DEFAULT_EXPAND = -1;
+    goto &ansifold;
+}
+
+sub ansicolrm {
+    local $DEFAULT_SEPARATE = "";
+    local $DEFAULT_COLRM    = 1;
+    goto &ansifold;
+}
+
+sub ansicut {
+    local $DEFAULT_SEPARATE = "";
+    goto &ansifold;
+}
+
 use Getopt::EX::Hashed 'has'; {
 
     Getopt::EX::Hashed->configure(DEFAULT => [ is => 'rw' ]);
@@ -47,6 +71,7 @@ use Getopt::EX::Hashed 'has'; {
     has runin      => '   =i  ' , min => 0, default => 4;
     has runout     => '   =i  ' , min => 0, default => 4;
     has runlen     => '   =i  ' , min => 0;
+    has margin     => '   =i  ' , min => 0;
     has nonewline  => ' n     ' ;
     has splitwide  => '   :s  ' , default => $DEFAULT_SPLITWIDE;
     has lefthalf   => '   =s  ' , default => "\N{LEFT HALF BLACK CIRCLE}";
@@ -236,7 +261,7 @@ sub doit {
 	map  { $_ => $app->$_ }
 	grep { defined $app->$_ }
 	qw(width boundary padding padchar prefix ambiguous
-	   linebreak runin runout
+	   margin linebreak runin runout
 	   splitwide lefthalf righthalf
 	   expand tabstyle tabstop tabhead tabspace discard)
     );
